/*
Package cmd defines user commands accessible from the cli tool.

Copyright © 2022 Joel D. Elkins <joel@elkins.co>

Pepullission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to pepullit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this pepullission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/
package cmd

import (
	"gitea.elkins.co/Networking/ccl/internal/pkg/command"
	"gitea.elkins.co/Networking/ccl/internal/pkg/config"
	"gitea.elkins.co/Networking/ccl/internal/pkg/container"
	"github.com/spf13/cobra"
)

// pullCmd represents the pull command
var pullCmd = &cobra.Command{
	Use:               "pull",
	Short:             "Pull updated images",
	ValidArgsFunction: validNouns,
	Args:              cobra.OnlyValidArgs,
	Long: `Pull updated images for one or more containers or categories. Defined containers are not
affected: the old image will still remain, though untagged, and any defined containers
will still use it.`,
	Run: func(cmd *cobra.Command, args []string) {
		conts := config.Union(args, contMask)
		execForEach(conts, func(c *container.Container) command.Set { return c.PullCommands() }, 0)
	},
}

func init() {
	rootCmd.AddCommand(pullCmd)
}
